<?php

namespace Litecms\FixedPlan\Providers;

use Illuminate\Support\ServiceProvider;

class FixedPlanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'fixed_plan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'fixed_plan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.fixed_plan', function ($app) {
            return $this->app->make('Litecms\FixedPlan\FixedPlan');
        });

                // Bind FixedPlans to repository
        $this->app->bind(
            'Litecms\FixedPlan\Interfaces\FixedPlansRepositoryInterface',
            \Litecms\FixedPlan\Repositories\Eloquent\FixedPlansRepository::class
        );

        $this->app->register(\Litecms\FixedPlan\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\FixedPlan\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\FixedPlan\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.fixed_plan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/fixed_plan.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/fixed_plan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/fixed_plan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
